==> I2P-Messenger_0.2.13b_Beta_src.zip: I2P-Messenger/gui/gui_icons.h <==
/***************************************************************************
 *   Copyright (C) 2008 by I2P-Messenger   				   *
 *   Messenger-Dev@I2P-Messenger   					   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef GUI_ICONS_H
#define GUI_ICONS_H

/*Icons */
#define ICON_QUIT              		":/icons/exit.png"
#define ICON_MINIMIZE          		":/icons/window_nofullscreen.png"
#define ICON_MAXIMIZE          		":/icons/window_fullscreen.png"
#define ICON_QTCHAT            		":/icons/userblue24.png"
#define ICON_CLOSE             		":/icons/exit.png"
#define ICON_NEWUSER			":/icons/add_user.png"
#define ICON_SETTINGS			":/icons/settings.png"
#define ICON_NEWUNREADMESSAGE   	":/icons/send.png"
#define ICON_USER_TRYTOCONNECT		":/icons/yellow.png"
#define ICON_USER_OFFLINE		":/icons/red.png"
#define ICON_USER_ONLINE		":/icons/green.png"
#define ICON_USER_WANTTOCHAT		":/icons/chatty.png"
#define ICON_USER_AWAY			":/icons/xa.png"
#define ICON_USER_DONT_DUSTURB		":/icons/dnd.png"
#define ICON_USER_INVISIBLE		":/icons/invisible.png"
#define ICON_DEBUGMESSAGES		":/icons/status_unknown.png"
#define ICON_MYDESTINATION		":/icons/editcopy.png"
#define ICON_ABOUT			":/icons/about.png"
#define ICON_SOUND_ON			":/icons/sound.png"
#define ICON_SOUND_OFF			":/icons/sound_off.png"
#define ICON_FILETRANSFER_RECIVE	":/icons/download.png"
#define ICON_FILETRANSFER_SEND		":/icons/upload.png"

#endif

==> I2P-Messenger_0.2.14_Beta_src.zip: I2P-Messenger/gui/gui_icons.h <==
/***************************************************************************
 *   Copyright (C) 2008 by I2P-Messenger   				   *
 *   Messenger-Dev@I2P-Messenger   					   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef GUI_ICONS_H
#define GUI_ICONS_H

/*Icons */
#define ICON_QUIT              		":/icons/exit.png"
#define ICON_MINIMIZE          		":/icons/window_nofullscreen.png"
#define ICON_MAXIMIZE          		":/icons/window_fullscreen.png"
#define ICON_QTCHAT            		":/icons/userblue24.png"
#define ICON_CLOSE             		":/icons/exit.png"
#define ICON_NEWUSER			        ":/icons/add_user.png"
#define ICON_SETTINGS			        ":/icons/settings.png"
#define ICON_NEWUNREADMESSAGE   	":/icons/mail_unread_new.png"
#define ICON_NEWUNREADMESSAGETRAY ":/icons/mail_get.png"
#define ICON_USER_TRYTOCONNECT		":/icons/yellow.png"
#define ICON_USER_OFFLINE		      ":/icons/red.png"
#define ICON_USER_ONLINE		      ":/icons/green.png"
#define ICON_USER_WANTTOCHAT		  ":/icons/chatty.png"
#define ICON_USER_AWAY			      ":/icons/xa.png"
#define ICON_USER_DONT_DUSTURB		":/icons/dnd.png"
#define ICON_USER_INVISIBLE		    ":/icons/invisible.png"
#define ICON_DEBUGMESSAGES		    ":/icons/status_unknown.png"
#define ICON_MYDESTINATION		    ":/icons/editcopy.png"
#define ICON_ABOUT			          ":/icons/about.png"
#define ICON_SOUND_ON			        ":/icons/sound.png"
#define ICON_SOUND_OFF			      ":/icons/sound_off.png"
#define ICON_FILETRANSFER_RECIVE	":/icons/download.png"
#define ICON_FILETRANSFER_SEND		":/icons/upload.png"
#define ICON_COPYBASE64           ":/icons/edit-copy22.png"

#endif
